---
meta:
  id: inspire_sat7
  endian: be
doc: |
  : InspireSat7 telemetry description file 
  : Version 0.0.1
  :
  : reference documentation 
  :      UVSQsat-Beacon description for web site 
  :  
  : This ksy file is used for different automatic code generation 
  :    - ksy file to programming language thanks o ksy compiler 
       - ksy file to graphwiz document thnaks to ksy compiler 
       - Ksy file to java textual display files thanks to JOSAST GeneratePOJOfromKSY tool (experimental)
       - Ksy file to FXML files and associated java files file thanks to JOSAST GeneratePOJOfromKSY tool (experimental)
       
  : Writing rules should be respected (see JOSAST project)
  :   - for interpreted value, variable should finish with 
  :      _raw if no interpretation is done 
  :      _c, _ma _v _dbm _mw according to the interpreted value 
  :   - the name of the interpreted value should be close to the displaed name (to limit rework)
  :      _c, _ma _v _dbm _mw are automaticaly converted to (C) (mA) (dbm) (mW)
  :
  :field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
  :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
  :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
  :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
  :field ctl: ax25_frame.ax25_header.ctl
  :field pid: ax25_frame.payload.pid
  
  

seq:
  - id: ax25_frame
    type: ax25_frame
    doc-ref: 'https://www.tapr.org/pub_ax25.html'

types:
  ax25_frame:
    seq:
      - id: ax25_header
        type: ax25_header
      - id: payload
        type:
          switch-on: ax25_header.ctl & 0x13
          cases:
            0x03: ui_frame
            0x13: ui_frame
            0x00: i_frame
            0x02: i_frame
            0x10: i_frame
            0x12: i_frame
            _: i_frame
            # 0x11: s_frame

  ax25_header:
    seq:
      - id: dest_callsign_raw
        type: callsign_raw
      - id: dest_ssid_raw
        type: ssid_mask
      - id: src_callsign_raw
        type: callsign_raw
      - id: src_ssid_raw
        type: ssid_mask
      - id: ctl
        type: u1

  callsign_raw:
    seq:
      - id: callsign_ror
        process: ror(1)
        size: 6
        type: callsign

  callsign:
    seq:
      - id: callsign
        type: str
        encoding: ASCII
        size: 6

  ssid_mask:
    seq:
      - id: ssid_mask
        type: u1
    instances:
      ssid:
        value: (ssid_mask & 0x0f) >> 1

  i_frame:
    seq:
      - id: pid
        type: u1
      - id: ax25_info
        size-eos: true

  ui_frame:
    seq:
      - id: pid
        type: u1
      - id: packet_primary_header
        type: packet_primary_header
      - id: packet_secondary_header
        type: packet_secondary_header
      - id: tlm
        type:
          switch-on: packet_secondary_header.sid
          cases:
            0x0E: amsat_ascii  
            0x0F: beacon
            0x10: ants_hk
            0x11: iobc_status
            0x12: iobc_hk
            0x13: lv_status
            0x14: msg_or_unknow
            0x15: ieps_hk_status
            0x16: trxvu_hk
            0x17: imtq_hk 
            0x18: trxvu_hk
            0x19: ants_status
            _: msg_or_unknow
      - id: ax25_info
        size-eos: true
# for command status and other message not recognised  
  msg_or_unknow:
    seq:
      - id: data
        size-eos: true
    instances:
     data_byte:
      value: data
        
# CCDS - primary packet header 
  packet_primary_header:
    seq:
      - id: packet_version_number
        type: b3
      - id: packet_id_packet_type
        type: b1
      - id: packet_id_secondary_header_flag
        type: b1
      - id: packet_id_application_process_id
        type: b11 
      - id: packet_sequence_control_secquence_flag
        type: b2
      - id: packet_sequence_control_count_or_name
        type: b14
      - id: packet_data_length
        type: u2
        
# CCDS - secondary  packet header 
  packet_secondary_header:
    seq:
      - id:  tm_packet_pus_version_number
        type: b4
      - id: spacecraft_time_reference_status
        type: b4
      - id: service_type_id
        type: u1
      - id: message_subtype_id
        type: u1
      - id: message_type_counter
        type: u2
      - id: destination_id
        type: u2
      - id: time
        type: u4
      - id: dummy1 # to verify 
        type: u2
      - id: dummy2 # to verify 
        type: u1
      - id: sid # used to identify the frame type
        type: u1
################################################################################
#
#   Ants Hk
# [X] TMTC SIDE A – Ants Temperature 16 Unsigned 16bits
# [X] TMTC SIDE A – Ants deployment status 16 Unsigned 16bits
# [X] TMTC SIDE A – Ants uptime 32 Unsigned 32bits
# [X] TMTC SIDE B – Ants Temperature 16 Unsigned 16bits
# [X] TMTC SIDE B – Ants deployment status 16 Unsigned 16bits
# [X] TMTC SIDE B – Ants uptime 32 Unsigned 32bits
# [X] IONO SIDE A – Ants Temperature 16 Unsigned 16bits
# [X] IONO SIDE A – Ants deployment status 16 Unsigned 16bits
# [X] IONO SIDE A – Ants uptime 32 Unsigned 32bits
# [X] IONO SIDE B – Ants Temperature 16 Unsigned 16bits
# [X] IONO SIDE B – Ants deployment status 16 Unsigned 16bits
# [X] IONO SIDE B – Ants uptime 32 Unsigned 32bits
#
################################################################################
  ants_hk:
    seq:
      - id: tmtc_side_a_ants_temperature
        type: u2
      - id: tmtc_side_a_ants_deployment_status
        type: u2
      - id: tmtc_side_a_ants_uptime
        type: u4
      - id: tmtc_side_b_ants_temperature
        type: u2
      - id: tmtc_side_b_ants_deployment_status
        type: u2
      - id: tmtc_side_b_ants_uptime
        type: u2
      - id: iono_side_a_ants_temperature
        type: u2
      - id: iono_side_a_ants_deployment_status
        type: u2
      - id: iono_side_a_ants_uptime
        type: u4
      - id: iono_side_b_ants_temperature
        type: u2
      - id: iono_side_b_ants_deployment_status
        type: u2
      - id: iono_side_b_ants_uptime
        type: u2

    instances:
     tmtc_side_a_ants_temperature_raw:
      value:  tmtc_side_a_ants_temperature
     tmtc_side_a_ants_deployment_status_raw:
      value: tmtc_side_a_ants_deployment_status
     tmtc_side_a_ants_uptime_raw:
      value: tmtc_side_a_ants_uptime
     tmtc_side_b_ants_temperature_raw:
      value: tmtc_side_b_ants_temperature
     tmtc_side_b_ants_deployment_status_raw:
      value: tmtc_side_b_ants_deployment_status
     tmtc_side_b_ants_uptime_raw:
      value: tmtc_side_b_ants_uptime
     iono_side_a_ants_temperature_raw:
      value:  iono_side_a_ants_temperature
     iono_side_a_ants_deployment_status_raw:
      value: iono_side_a_ants_deployment_status
     iono_side_a_ants_uptime_raw:
      value: iono_side_a_ants_uptime
     iono_side_b_ants_temperature_raw:
      value: iono_side_b_ants_temperature
     iono_side_b_ants_deployment_status_raw:
      value: iono_side_b_ants_deployment_status
     iono_side_b_ants_uptime_raw:
      value: iono_side_b_ants_uptime

################################################################################
#
#   Ants status
# [] Data Description Size in bits Data Type
# [] TMTC SIDE A – deployment count Antenna 1 8 Unsigned 8bits
# [] TMTC SIDE A – deployment count Antenna 2 8 Unsigned 8bits
# [] TMTC SIDE A – deployment count Antenna 3 8 Unsigned 8bits
# [] TMTC SIDE A – deployment count Antenna 4 8 Unsigned 8bits
# [] TMTC SIDE A – deployment time Antenna 1 16 Unsigned 16bits
# [] TMTC SIDE A – deployment time Antenna 2 16 Unsigned 16bits
# [] TMTC SIDE A – deployment time Antenna 3 16 Unsigned 16bits
# [] TMTC SIDE A – deployment time Antenna 4 16 Unsigned 16bits
# [] TMTC SIDE B – deployment count Antenna 1 8 Unsigned 8bits
# [] TMTC SIDE B – deployment count Antenna 2 8 Unsigned 8bits
# [] TMTC SIDE B – deployment count Antenna 3 8 Unsigned 8bits
# [] TMTC SIDE B – deployment count Antenna 4 8 Unsigned 8bits
# [] TMTC SIDE B – deployment time Antenna 1 16 Unsigned 16bits
# [] TMTC SIDE B – deployment time Antenna 2 16 Unsigned 16bits
# [] TMTC SIDE B – deployment time Antenna 3 16 Unsigned 16bits
# [] TMTC SIDE B – deployment time Antenna 4 16 Unsigned 16bits
# [] IONO SIDE A – deployment count Antenna 1 8 Unsigned 8bits
# [] IONO SIDE A – deployment count Antenna 2 8 Unsigned 8bits
# [] IONO SIDE A – deployment count Antenna 3 8 Unsigned 8bits
# [] IONO SIDE A – deployment count Antenna 4 8 Unsigned 8bits
# [] IONO SIDE A – deployment time Antenna 1 16 Unsigned 16bits
# [] IONO SIDE A – deployment time Antenna 2 16 Unsigned 16bits
# [] IONO SIDE A – deployment time Antenna 3 16 Unsigned 16bits
# [] IONO SIDE A – deployment time Antenna 4 16 Unsigned 16bits
# [] IONO SIDE B – deployment count Antenna 1 8 Unsigned 8bits
# [] IONO SIDE B – deployment count Antenna 2 8 Unsigned 8bits
# [] IONO SIDE B – deployment count Antenna 3 8 Unsigned 8bits
# [] IONO SIDE B – deployment count Antenna 4 8 Unsigned 8bits
# [] IONO SIDE B – deployment time Antenna 1 16 Unsigned 16bits
# [] IONO SIDE B – deployment time Antenna 2 16 Unsigned 16bits
# [] IONO SIDE B – deployment time Antenna 3 16 Unsigned 16bits
# [] IONO SIDE B – deployment time Antenna 4 16 Unsigned 16bits
#
################################################################################
  ants_status:
    seq:
      - id: tmtc_side_a_deployment_count_antenna_1
        type: u1
      - id: tmtc_side_a_deployment_count_antenna_2
        type: u1
      - id: tmtc_side_a_deployment_count_antenna_3
        type: u1
      - id: tmtc_side_a_deployment_count_antenna_4
        type: u1
      - id: tmtc_side_a_deployment_time_antenna_1
        type: u2
      - id: tmtc_side_a_deployment_time_antenna_2
        type: u2
      - id: tmtc_side_a_deployment_time_antenna_3
        type: u2
      - id: tmtc_side_a_deployment_time_antenna_4
        type: u2
      - id: tmtc_side_b_deployment_count_antenna_1
        type: u1
      - id: tmtc_side_b_deployment_count_antenna_2
        type: u1
      - id: tmtc_side_b_deployment_count_antenna_3
        type: u1
      - id: tmtc_side_b_deployment_count_antenna_4
        type: u1
      - id: tmtc_side_b_deployment_time_antenna_1
        type: u2
      - id: tmtc_side_b_deployment_time_antenna_2
        type: u2
      - id: tmtc_side_b_deployment_time_antenna_3
        type: u2
      - id: tmtc_side_b_deployment_time_antenna_4
        type: u2
      - id: iono_side_a_deployment_count_antenna_1
        type: u1
      - id: iono_side_a_deployment_count_antenna_2
        type: u1
      - id: iono_side_a_deployment_count_antenna_3
        type: u1
      - id: iono_side_a_deployment_count_antenna_4
        type: u1
      - id: iono_side_a_deployment_time_antenna_1
        type: u2
      - id: iono_side_a_deployment_time_antenna_2
        type: u2
      - id: iono_side_a_deployment_time_antenna_3
        type: u2
      - id: iono_side_a_deployment_time_antenna_4
        type: u2
      - id: iono_side_b_deployment_count_antenna_1
        type: u1
      - id: iono_side_b_deployment_count_antenna_2
        type: u1
      - id: iono_side_b_deployment_count_antenna_3
        type: u1
      - id: iono_side_b_deployment_count_antenna_4
        type: u1
      - id: iono_side_b_deployment_time_antenna_1
        type: u2
      - id: iono_side_b_deployment_time_antenna_2
        type: u2
      - id: iono_side_b_deployment_time_antenna_3
        type: u2
      - id: iono_side_b_deployment_time_antenna_4
        type: u2
    instances:
     tmtc_side_a_deployment_count_antenna_1_raw:
      value: tmtc_side_a_deployment_count_antenna_1     
     tmtc_side_a_deployment_count_antenna_2_raw:
      value: tmtc_side_a_deployment_count_antenna_2
     tmtc_side_a_deployment_count_antenna_3_raw:
      value: tmtc_side_a_deployment_count_antenna_3
     tmtc_side_a_deployment_count_antenna_4_raw:
      value: tmtc_side_a_deployment_count_antenna_4
     tmtc_side_a_deployment_time_antenna_1_raw:
      value: tmtc_side_a_deployment_time_antenna_1
     tmtc_side_a_deployment_time_antenna_2_raw:
       value: tmtc_side_a_deployment_time_antenna_2
     tmtc_side_a_deployment_time_antenna_3_raw:
      value: tmtc_side_a_deployment_time_antenna_3
     tmtc_side_a_deployment_time_antenna_4_raw:
      value: tmtc_side_a_deployment_time_antenna_4
     tmtc_side_b_deployment_count_antenna_1_raw:
      value: tmtc_side_b_deployment_count_antenna_1
     tmtc_side_b_deployment_count_antenna_2_raw:
      value: tmtc_side_b_deployment_count_antenna_2
     tmtc_side_b_deployment_count_antenna_3_raw:
      value: tmtc_side_b_deployment_count_antenna_3
     tmtc_side_b_deployment_count_antenna_4_raw:
      value: tmtc_side_b_deployment_count_antenna_4
     tmtc_side_b_deployment_time_antenna_1_raw:
      value: tmtc_side_b_deployment_time_antenna_1
     tmtc_side_b_deployment_time_antenna_2_raw:
      value: tmtc_side_b_deployment_time_antenna_2
     tmtc_side_b_deployment_time_antenna_3_raw:
      value: tmtc_side_b_deployment_time_antenna_3
     tmtc_side_b_deployment_time_antenna_4_raw:
      value: tmtc_side_b_deployment_time_antenna_4
     iono_side_a_deployment_count_antenna_1_raw:
      value: iono_side_a_deployment_count_antenna_1
     iono_side_a_deployment_count_antenna_2_raw:
      value: iono_side_a_deployment_count_antenna_2
     iono_side_a_deployment_count_antenna_3_raw:
      value: iono_side_a_deployment_count_antenna_3
     iono_side_a_deployment_count_antenna_4_raw:
      value: iono_side_a_deployment_count_antenna_4
     iono_side_a_deployment_time_antenna_1_raw:
      value: iono_side_a_deployment_time_antenna_1
     iono_side_a_deployment_time_antenna_2_raw:
      value: iono_side_a_deployment_time_antenna_2
     iono_side_a_deployment_time_antenna_3_raw:
      value: iono_side_a_deployment_time_antenna_3
     iono_side_a_deployment_time_antenna_4_raw:
      value: iono_side_a_deployment_time_antenna_4
     iono_side_b_deployment_count_antenna_1_raw:
      value: iono_side_b_deployment_count_antenna_1
     iono_side_b_deployment_count_antenna_2_raw:
      value: iono_side_b_deployment_count_antenna_2
     iono_side_b_deployment_count_antenna_3_raw:
      value: iono_side_b_deployment_count_antenna_3
     iono_side_b_deployment_count_antenna_4_raw:
      value: iono_side_b_deployment_count_antenna_4
     iono_side_b_deployment_time_antenna_1_raw:
      value: iono_side_b_deployment_time_antenna_1
     iono_side_b_deployment_time_antenna_2_raw:
      value: iono_side_b_deployment_time_antenna_2
     iono_side_b_deployment_time_antenna_3_raw:
      value: iono_side_b_deployment_time_antenna_3
     iono_side_b_deployment_time_antenna_4_raw:
      value: iono_side_b_deployment_time_antenna_4

################################################################################
#
#   OBC Status

# [] dummy 8 Unsigned 8bits
# [] SPI Command Status 8 Unsigned 8bits
# [] Supervisor Index of subsystem 8 Unsigned 8bits
# [] Supervisor Major Version 8 Unsigned 8bits
# [] Supervisor Minor Version 8 Unsigned 8bits
# [] Supervisor Patch Version 8 Unsigned 8bits
# [] Supervisor Git head Version 32 Unsigned 32bits
# [] Supervisor Serial Number 16 Unsigned 16bits
# [] Compilation Information 152
# [] Clock Speed 8 Unsigned 8bits
# [] Code Type 8 Unsigned 8bits
# [] CRC 8 8 Unsigned 8bits
# [] SW Mode 8 Unsigned 8bits
# [] Last Reset Reason 8 Unsigned 8bits
# [] Reserved 8 Unsigned 8bits
# [] nbReset 8 Unsigned 8bits
# [] Reserved 8 Unsigned 8bits
# [] Deploy Antennas system8 Unsigned 8bits
# [] Nb Tm since first start 32 Unsigned 32bits
# [] Nb Tc since first start 32 Unsigned 32bits
# [] Nb Tc ping since first start 32 Unsigned 32bits
# [] Nb Bad Tc since first start 32 Unsigned 32bits
# [] Nb Tm in Sdcard 32 Unsigned 32bits
# [] Sdcard Status 8 Unsigned 8bits
# [] Sdcard Last Error 32 Unsigned 32bits
# [] Old Time TM in Sdcard 56 Time in 7 bytes
# [] New Time TM in Sdcard 56 Time in 7 bytes
#
################################################################################
  iobc_status:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_index_of_subsystem
        type: u1
      - id: supervisor_major_version
        type: u1
      - id: supervisor_minor_version
        type: u1
      - id: supervisor_patch_version
        type: u1
      - id: supervisor_git_head_version
        type: u4
      - id: supervisor_serial_number
        type: u2
      - id: compilation_information
        size: 19
      - id: clock_speed
        type: u1
      - id: code_type
        type: u1
      - id: crc_8
        type: u1
      - id: sw_mmode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reserved 
        type: u1
      - id: nb_reset
        type: u1
      - id: reserved2 
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_tc_ping_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: sdcard_status
        type: u1
      - id: sdcard_last_error
        type: u4
      - id: old_time_t_m_in_sdcard
        type: b56
      - id: new_time_t_m_in_sdcard
        type: b56
    instances:
      dummydummy:
       value: dummy
      spi_command_status_raw:
       value: spi_command_status
      supervisor_index_of_subsystem_raw:
       value: supervisor_index_of_subsystem
      supervisor_major_version_raw:
       value: supervisor_major_version
      supervisor_minor_version_raw:
       value: supervisor_minor_version
      supervisor_patch_version_raw:
       value: supervisor_patch_version
      supervisor_git_head_version_raw:
       value: supervisor_git_head_version
      supervisor_serial_number_raw:
       value: supervisor_serial_number
      compilation_information_byte:
       value: compilation_information
      clock_speed_raw:
       value: clock_speed
      code_type_raw:
       value: code_type
      crc_8_raw:
       value: crc_8
      sw_mmode_raw:
       value: sw_mmode
      last_reset_reason_raw:
       value: last_reset_reason
      reserved_raw:
       value: reserved
      nb_reset_raw:
       value: nb_reset
      reserved2_raw: 
       value: reserved2
      deploy_antennas_system_raw:
       value: deploy_antennas_system
      nb_tm_since_first_start_raw:
       value: nb_tm_since_first_start
      nb_tc_since_first_start_raw:
       value: nb_tc_since_first_start
      nb_tc_ping_since_first_start_raw:
       value: nb_tc_ping_since_first_start
      nb_bad_tc_since_first_start_raw:
       value: nb_bad_tc_since_first_start
      nb_tm_in_sdcard_raw:
       value: nb_tm_in_sdcard
      sdcard_status_raw:
       value: sdcard_status
      sdcard_last_error_raw:
       value: sdcard_last_error
      old_time_t_m_in_sdcard_raw:
       value: old_time_t_m_in_sdcard
      new_time_t_m_in_sdcard_raw:
       value: new_time_t_m_in_sdcard    

################################################################################
#
#   IOBC HK
#    Data Description Description Size in bits Data type
# [] Dummy The first as always is a dummy byte 8 Unsigned 8bits
# [] SPI Command Status The second is a SPI Command Status. 8 Unsigned 8bits
# [] Supervisor enable 8 Unsigned 8bits
# [] Supervisor Uptime Supervisor Controller Uptime. 32 Unsigned 32bits
# [] iOBC Uptime IOBC Uptime as measured by Supervisor Controller. 32 Unsigned 32bits
# [] iOBC Reset Count IOBC Reset Count. 32 Unsigned 32bits
# [] iOBC Measure Temperature Temperature of the iOBC 16 Unsigned 16bits
# [] iOBC Measure 3V3 in Voltage Measurement of the 3.3V in 16 Unsigned 16bits
# [] iOBC Measure 3V3 Voltage Measurement of the 3.3V 16 Unsigned 16bits
# [] iOBC Measure 2VR reference Voltage Measurement of the 2.5V reference 16 Unsigned 16bits
# [] iOBC Measure 1V8 Voltage Measurement of the 1.8V 16 Unsigned 16bits
# [] iOBC Measure 1V0 Voltage Measurement of the 1.0V 16 Unsigned 16bits
# [] iOBC Measure Current 3V3 Current Measurement of the 3.3V 16 Unsigned 16bits
# [] iOBC Measure Current 1V8 Current Measurement of the 1.8V 16 Unsigned 16bits
# [] iOBC Measure Current 1V0 Current Measurement of the 1.0V 16 Unsigned 16bits
# [] iOBC Measure volt RTC Voltage Measurement of the RTC 16 Unsigned 16bits
# [] iOBC ADC Update Flag ADC Update Flag. 8 Unsigned 8bits
# [] iOBC CRC8 CRC 8 on previous data (dummy to ADC update flag) 8 Unsigned 8bits
# [] Photodiode 1 Photodiode Measurement of the Panel 1 16 Unsigned 16bits
# [] Photodiode 2 Photodiode Measurement of the Panel 2 16 Unsigned 16bits
# [] Photodiode 3 Photodiode Measurement of the Panel 3 16 Unsigned 16bits
# [] Photodiode 4 Photodiode Measurement of the Panel 4 16 Unsigned 16bits
# [] Photodiode 5 Photodiode Measurement of the Panel 5 16 Unsigned 16bits
# [] Photodiode 6 Photodiode Measurement of the Panel 6 16 Unsigned 16bits
# [] Panel Temperature 1 Temperature Measurement of the Panel 1 32 Signed 32bits
# [] Panel Temperature 2 Temperature Measurement of the Panel 2 32 Signed 32bits
# [] Panel Temperature 3 Temperature Measurement of the Panel 3 32 Signed 32bits
# [] Panel Temperature 4 Temperature Measurement of the Panel 4 32 Signed 32bits
# [] Panel Temperature 5 Temperature Measurement of the Panel 5 32 Signed 32bits
#
################################################################################          
  iobc_hk:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_enable_status
        type: u1
      - id: supervisor_uptime
        type: u4
      - id: iobc_uptime
        type: u4
      - id: iobc_reset_count
        type: u4
      - id: iobc_measure_temperature
        type: u2
      - id: iobc_measure_3v3_in
        type: u2
      - id: iobc_measure_3v3
        type: u2
      - id: iobc_measure_2v_reference
        type: u2
      - id: iobc_measure_1v8
        type: u2
      - id: iobc_measure_1v0
        type: u2
      - id: iobc_measure_current_3v3
        type: u2
      - id: iobc_measure_current_1v8
        type: u2
      - id: iobc_measure_current_1v0
        type: u2
      - id: iobc_measure_volt_rtc
        type: u2
      - id: iobc_adc_update_flag
        type: u1
      - id: iobc_crc8
        type: u1
      - id: photodiode_1
        type: u2
      - id: photodiode_2
        type: u2
      - id: photodiode_3
        type: u2
      - id: photodiode_4
        type: u2
      - id: photodiode_5
        type: u2
      - id: photodiode_6
        type: u2
      - id: panel_temperature_1
        type: s4
      - id: panel_temperature_2
        type: s4
      - id: panel_temperature_3
        type: s4
      - id: panel_temperature_4
        type: s4
      - id: panel_temperature_5
        type: s4
      - id: panel_temperature_6
        type: s4
    instances:
      dummy_raw:
        value: dummy
      spi_command_status_raw:
        value: spi_command_status
      supervisor_enable_status_raw:
        value: supervisor_enable_status
      supervisor_uptime_raw:
        value: supervisor_uptime
      iobc_uptime_raw:
        value: iobc_uptime
      iobc_reset_count_raw:
        value: iobc_reset_count
      iobc_measure_temperature_raw:
        value: iobc_measure_temperature
      iobc_measure_3v3_in_raw:
        value: iobc_measure_3v3_in
      iobc_measure_3v3_raw:
        value: iobc_measure_3v3
      iobc_measure_2v_reference_raw:
        value: iobc_measure_2v_reference
      iobc_measure_1v8_raw:
        value: iobc_measure_1v8
      iobc_measure_1v0_raw:
        value: iobc_measure_1v0
      iobc_measure_current_3v3_raw:
        value: iobc_measure_current_3v3
      iobc_measure_current_1v8_raw:
        value: iobc_measure_current_1v8
      iobc_measure_current_1v0_raw:
        value: iobc_measure_current_1v0
      iobc_measure_volt_rtc_raw:
        value: iobc_measure_volt_rtc
      iobc_adc_update_flag_raw:
        value: iobc_adc_update_flag
      iobc_crc8_raw:
        value: iobc_crc8
      photodiode1_raw:
        value: photodiode_1
      photodiode2_raw:
        value: photodiode_2
      photodiode3_raw:
        value: photodiode_3
      photodiode4_raw:
        value: photodiode_4
      photodiode5_raw:
        value: photodiode_5
      photodiode6_raw:
        value: photodiode_6
      panel_temperature_1_c:
        value:  panel_temperature_1 / 1024.0
      panel_temperature_2_c:
        value:  panel_temperature_2 / 1024.0
      panel_temperature_3_c:
        value:  panel_temperature_3 / 1024.0
      panel_temperature_4_c:
        value:  panel_temperature_4 / 1024.0
      panel_temperature_5_c:
        value:  panel_temperature_5 / 1024.0
      panel_temperature_6_c:
        value:  panel_temperature_6 / 1024.0


################################################################################
#
#   lv_status
#   
#  ee Data Description   Size in bits  Data Type
#  Mode Plateform  8  Unsigned 8bits    
#  PF Number of Seconds in current mode   24  Unsigned 24bits
# Mode Imtq  8  Unsigned 8bits  
# Imtq Number of Seconds in current mode  24  Unsigned 24bits
# Mode Trxvu  8  Unsigned 8bits  
# PF Number of Seconds in current mode   24  Unsigned 24bits
# Nb TM in PF FIFO  24  Unsigned 24bits
# Mode Payload Capteurs  8  Unsigned 8bits
# CAPTEURS number of Seconds in current mode  24  Unsigned 24bits
# Nb TM in Capteurs payload FIFO  24  Unsigned 24bits
# Mode Payload IMU  8  Unsigned 8bits
# IMU number of Seconds in current mode  24  Unsigned 24bits
# Nb TM in IMU payload FIFO  24  Unsigned 24bits
# Mode Payload IONO  8  Unsigned 8bits
# IONO number of Seconds in current mode  24  Unsigned 24bits
# Nb TM in IONO payload FIFO  24  Unsigned 24bits
# Mode Payload LIFI  8  Unsigned 8bits
# LIFI number of Seconds in current mode  24  Unsigned 24bits
# Nb TM in LIFI payload FIFO  24  Unsigned 24bits
# Mode Payload SPINO  8  Unsigned 8bits
# SPINO number of Seconds in current mode  24  Unsigned 24bits
# Nb TM in SPINO payload FIFO  24  Unsigned 24bits
# Number of file in SD for HKTM PF  12  Unsigned 12bits
# Number of file in SD for PLTM CAPTEURS  12  Unsigned 12bits
# Number of file in SD for PLTM IMU  12  Unsigned 12bits
# Number of file in SD for PLTM IONO  12  Unsigned 12bits
# Number of file in SD for PLTM LIFI  12  Unsigned 12bits
# Number of file in SD for PLTM SPINO  12  Unsigned 12bits
#
################################################################################

  lv_status:
    seq:
      - id: mode_plateform
        type: u8
      - id: p_f_number_of_seconds_in_current_mode
        type: b24
      - id: mode_imtq
        type: u8
      - id: imtq_number_of_seconds_in_current_mode
        type: b24
      - id: mode_trxvu
        type: u8
      - id:  p_f_number_of_seconds_in_current_modebis 
        type: b24
      - id:  nb_t_m_in_pf_fifo
        type: b24
      - id:  mode_payload_capteurs
        type: u8
      - id:  capteurs_number_of_seconds_in_current_mode
        type: b24
      - id:  nb_t_m_in_capteurs_payload_fifo
        type: b24
      - id:  mode_payload_i_m_u
        type: u8
      - id:  imu_number_of_seconds_in_current_mode
        type: b24
      - id:  nb_t_m_in_i_m_u_payload_fifo
        type: b24
      - id:  mode_payload_iono
        type: u8
      - id:  iono_number_of_seconds_in_current_mode
        type: b24
      - id:  nb_t_m_in_iono_payload_fifo
        type: b24
      - id:  mode_payload_l_i_f_i
        type: u8
      - id:  l_i_f_i_number_of_seconds_in_current_mode
        type: b24
      - id:  nb_t_m_in_l_i_f_i_payload_fifo
        type: b24
      - id:  mode_payload_s_p_i_n_o
        type: u8
      - id:  s_p_i_n_o_number_of_seconds_in_current_mode
        type: b24
      - id:  nb_tm_in_s_p_i_n_o_payload_fifo
        type: b24
      - id:  number_of_file_in_s_d_for_hktm_pf
        type: u8
      - id:  number_of_file_in_s_d_pltm_capteurs
        type: b12
      - id:  number_of_file_in_s_d_pltm_imu
        type: b12
      - id:  number_of_file_in_s_d_pltm_iono
        type: b12
      - id:  number_of_file_in_s_d_pltm_lifi
        type: b12
      - id:  number_of_file_in_s_d_pltm_spino
        type: b12

    instances:
      mode_plateform_raw:
        value: mode_plateform
      p_f_number_of_seconds_in_current_mode_raw:
        value: p_f_number_of_seconds_in_current_mode_
      mode_imtq_raw:
        value: mode_imtq
      imtq_number_of_seconds_in_current_mode_raw:
        value: imtq_number_of_seconds_in_current_mode
      mode_trxvu_raw:
        value: mode_trxvu
      p_f_number_of_seconds_in_current_mode_raw:
        value: p_f_number_of_seconds_in_current_modebis
      nb_t_m_in_pf_fifo_raw:
        value: nb_t_m_in_pf_fifo
      mode_payload_capteurs_raw:
        value: mode_payload_capteurs
      capteurs_number_of_seconds_in_current_mode_raw:
        value: capteurs_number_of_seconds_in_current_mode
      nb_t_m_in_capteurs_payload_fifo_raw:
        value: nb_t_m_in_capteurs_payload_fifo
      mode_payload_i_m_u_raw:
        value: mode_payload_i_m_u
      imu_number_of_seconds_in_current_mode_raw:
        value: imu_number_of_seconds_in_current_mode
      nb_t_m_in_i_m_u_payload_fifo_raw:
        value: nb_t_m_in_i_m_u_payload_fifo
      mode_payload_iono_raw:
        value: mode_payload_iono
      iono_number_of_seconds_in_current_mode_raw:
        value: iono_number_of_seconds_in_current_mode
      nb_t_m_in_iono_payload_fifo_raw:
        value: nb_t_m_in_iono_payload_fifo
      mode_payload_l_i_f_i_raw:
        value: mode_payload_l_i_f_i
      l_i_f_i_number_of_seconds_in_current_mode_raw:
        value: l_i_f_i_number_of_seconds_in_current_mode
      nb_t_m_in_l_i_f_i_payload_fifo_raw:
        value: nb_t_m_in_l_i_f_i_payload_fifo
      mode_payload_s_p_i_n_o_raw:
        value: mode_payload_s_p_i_n_o
      s_p_i_n_o_number_of_seconds_in_current_mode_raw:
        value: s_p_i_n_o_number_of_seconds_in_current_mode
      nb_tm_in_s_p_i_n_o_payload_fifo_raw:
        value: nb_tm_in_s_p_i_n_o_payload_fifo
      number_of_file_in_s_d_for_hktm_pf_raw:
        value: number_of_file_in_s_d_for_hktm_pf
      number_of_file_in_s_d_pltm_capteurs_raw:
        value: number_of_file_in_s_d_pltm_capteurs
      number_of_file_in_s_d_pltm_imu_raw:
        value: number_of_file_in_s_d_pltm_imu
      number_of_file_in_s_d_pltm_iono_raw:
        value: number_of_file_in_s_d_pltm_iono
      number_of_file_in_s_d_pltm_lifi_raw:
        value: number_of_file_in_s_d_pltm_lifi
      number_of_file_in_s_d_pltm_spino_raw:
        value: number_of_file_in_s_d_pltm_spino


################################################################################
#
#   ieps HK status
#
#
#
################################################################################

  ieps_hk_status:
      seq:
      - id: h_k_stid 
        type: u1
      - id: h_k_ivid 
        type: u1
      - id: h_k_rc 
        type: u1
      - id: h_k_bid 
        type: u1
      - id: h_k_cmderr 
        type: b4
      - id: h_k_stat 
        type: b4
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: v_dist_input_raw
        type: u2
      - id: i_dist_input_raw
        type: u2
      - id: p_dist_input_raw
        type: u2
      - id: v_batt_input_raw
        type: u2
      - id: i_batt_input_raw
        type: u2
      - id: p_batt_input_raw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp_2_raw
        type: u2
      - id: bat_temp_3_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_obc_00
        type: u2
      - id: i_obc_00
        type:  u2
      - id: p_obc_00
        type:  u2
      - id: v_obc_01
        type: u2
      - id: i_obc_01
        type:  u2
      - id: p_obc_01
        type:  u2
      - id: v_obc_02
        type: u2
      - id: i_obc_02
        type:  u2
      - id: p_obc_02
        type:  u2
      - id: v_obc_03
        type: u2
      - id: i_obc_03
        type:  u2
      - id: p_obc_03
        type:  u2
      - id: v_obc_04
        type: u2
      - id: i_obc_04
        type:  u2
      - id: p_obc_04
        type:  u2
      - id: v_obc_05
        type: u2
      - id: i_obc_05
        type:  u2
      - id: p_obc_05
        type:  u2
      - id: v_obc_06
        type: u2
      - id: i_obc_06
        type:  u2
      - id: p_obc_06
        type:  u2
      - id: v_obc_07
        type: u2
      - id: i_obc_07
        type:  u2
      - id: p_obc_07
        type:  u2
      - id: v_obc_08
        type: u2
      - id: i_obc_08
        type:  u2
      - id: p_obc_08
        type:  u2
      - id: cc1
        size: 8
      - id: cc2
        size: 8
      - id: cc3
        size: 8
      - id: status_stid 
        type: u1
      - id: status_ivid 
        type: u1
      - id: status_rc 
        type: u1
      - id: status_bid 
        type: u1
      - id: status_cmderr 
        type: b4
      - id: status_stat 
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2
      instances:
        h_k_stid_raw: 
         value: h_k_stid
        h_k_ivid_raw:  
         value: h_k_ivid
        h_k_rc_raw:  
         value: h_k_rc
        h_k_bid_raw:  
         value: h_k_bid
        h_k_cmderr_raw:  
         value: h_k_cmderr
        h_k_stat_raw:  
         value: h_k_stat
        volt_brd_sup_raw_v: 
         value: volt_brd_sup_raw * 1000.0 / 819.0
        # ?? To be check - not coherent 
        temp_raw_t: 
         value: ((temp_raw -1168)*220.0/9.0 )/ 100.0
        v_dist_input_raw_v: 
         value: (v_dist_input_raw * 125.0/128.0)/ 1000.0
        i_dist_input_raw_ma: 
         value: i_dist_input_raw * 3125.0/10240.0 
        p_dist_input_raw_mw: 
         value: p_dist_input_raw *3125.0 / 3200.0
        v_batt_input_raw_v: 
         value: (v_batt_input_raw * 125.0/128.0)/ 1000.0
        i_batt_input_raw_ma: 
         value: 1000.0 * (i_batt_input_raw * 3125.0/10240.0)
        p_batt_input_raw_mw:
         value: p_batt_input_raw *3125.0 / 3200.0
        stat_obc_on_raw: 
         value: stat_obc_on
        stat_obc_ocf_raw: 
         value: stat_obc_ocf
        bat_stat_raw: 
         value: bat_stat
        bat_temp_2_raw_t: 
         value: bat_temp_2_raw * -0.047715407918 +98.38261483
        bat_temp_3_raw_t: 
         value: bat_temp_3_raw * -0.047715407918 +98.38261483
        volt_vd0_raw:
          value: volt_vd0
        volt_vd1_raw:
          value: volt_vd1
        volt_vd2_raw: 
          value: volt_vd2
        v_obc_00_v:
         value: (v_obc_00  *125.0/128.0)/ 1000.0
        i_obc_00_ma:
         value: i_obc_00 *3125.0/20480.0
        p_obc_00_mw:
         value: p_obc_00 *3125.0 / 6400.0
        v_obc_01_v:
         value: ( v_obc_01  *125.0/128.0)/ 1000.0
        i_obc_01_ma:
         value: i_obc_01 *3125.0/20480.0
        p_obc_01_mw:
         value: p_obc_01 *3125.0 / 6400.0
        v_obc_02_v:
         value: (v_obc_02  *125.0/128.0)/ 1000.0
        i_obc_02_ma:
         value: i_obc_02 *3125.0/20480.0
        p_obc_02_mw:
         value: p_obc_02 *3125.0 / 6400.0   
        v_obc_03_v:
         value: (v_obc_03  *125.0/128.0)/ 1000.0
        i_obc_03_ma:
         value: i_obc_03 *3125.0/20480.0
        p_obc_03_mw:
         value: p_obc_03 *3125.0 / 6400.0
        v_obc_04_v:
         value: (v_obc_04  *125.0/128.0)/ 1000.0
        i_obc_04_ma:
         value: i_obc_04 *3125.0/20480.0
        p_obc_04_mw:
         value: p_obc_04 *3125.0 / 6400.0
        v_obc_05_v:
         value: (v_obc_05  *125.0/128.0)/ 1000.0
        i_obc_05_ma:
         value: i_obc_05 *3125.0/20480.0
        p_obc_05_mw:
         value: p_obc_05 *3125.0 / 6400.0
        v_obc_06_v:
         value: (v_obc_06  *125.0/128.0)/ 1000.0
        i_obc_06_ma:
         value: i_obc_06 *3125.0/20480.0
        p_obc_06_mw :
         value: p_obc_06 *3125.0 / 6400.0
        v_obc_07_v:
         value: (v_obc_07  *125.0/128.0)/ 1000.0
        i_obc_07_ma:
         value: i_obc_07 *3125.0/20480.0
        p_obc_07_mw :
         value: p_obc_07 *3125.0 / 6400.0
        v_obc_08_v:
         value: (v_obc_08  *125.0/128.0)/ 1000.0
        i_obc_08_ma:
         value: i_obc_08 *3125.0/20480.0
        p_obc_08_mw :
         value: p_obc_08 *3125.0 / 6400.0
        cc1_byte:
         value: cc1
        cc2_byte:
         value: cc2
        cc3_byte:
         value: cc3
        status_stid_raw: 
         value: status_stid
        status_ivid_raw:
         value: status_ivid
        status_rc_raw:
         value: status_rc
        status_bid_raw: 
         value: status_bid
        status_cmderr_raw: 
         value: status_cmderr
        status_stat_raw: 
         value: status_stat
        mode_raw:
         value: mode
        conf_raw:
         value: conf
        reset_cause_raw:
         value: reset_cause
        uptime_raw:
         value: uptime
        error_raw:
         value: error
        rc_cnt_pwron_raw:
         value: rc_cnt_pwron
        rc_cnt_wdg_raw:
         value: rc_cnt_wdg
        rc_cnt_cmd_raw:
         value: rc_cnt_cmd
        rc_cnt_mcu_raw:
         value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
         value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
         value: prevcmd_elapsed

################################################################################
#
#   trxvurx HK
#  X Trxvu_Rx Instantaneous received signal Doppler offset at the receiver port   12   Unsigned 12bits 
#  X Trxvu_Rx Instantaneous received signal strength at the receiver port   12   Unsigned 12bits 
#  X Trxvu_Rx Supply voltage   12   Unsigned 12bits 
#  X Trxvu_Rx Total supply current   12   Unsigned 12bits 
#  X Trxvu_Rx Transmitter current   12   Unsigned 12bits 
#  X Trxvu_Rx Receiver current   12   Unsigned 12bits 
#  X Trxvu_Rx Power amplifier current   12   Unsigned 12bits 
#  X Trxvu_Rx Power amplifier temperature   12   Unsigned 12bits 
#  X Trxvu_Rx Local oscillator temperature   12   Unsigned 12bits 
#  X Trxvu_Rx Uptime   32   Unsigned 32bits 
#  X Trxvu_Tx Instantaneous RF reflected power from transmitter port   12   Unsigned 12bits 
#  X Trxvu_Tx Instantaneous RF forward power from transmitter port   12   Unsigned 12bits 
#  X Trxvu_Tx Supply voltage   12   Unsigned 12bits 
#  X Trxvu_Tx Total supply current   12   Unsigned 12bits 
#  X Trxvu_Tx Transmitter current   12   Unsigned 12bits 
#  X Trxvu_Tx Receiver current   12   Unsigned 12bits 
#  Trxvu_Tx Power amplifier current   12   Unsigned 12bits 
#  Trxvu_Tx Power amplifier temperature   12   Unsigned 12bits 
#  Trxvu_Tx Local oscillator temperature   12   Unsigned 12bits 
#  Trxvu_Tx Uptime   32   Unsigned 32bits 
#  Trxvu_Tx State   8   Unsigned 8bits 
#
################################################################################       
  trxvu_hk:
    seq:
      - id: trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvurx_supply_voltage
        type: b12
      - id: trxvurx_total_supply_current
        type: b12
      - id: trxvurx_transmitter_current
        type: b12
      - id: trxvurx_receiver_current
        type: b12
      - id: trxvurx_power_amplifier_current
        type: b12
      - id: trxvurx_power_amplifier_temperature
        type: b12
      - id: trxvurx_local_oscillator_temperature
        type: b12
      - id: trxvu_rx_uptime
        type: u4
      - id: trxvutx_instantaneous_rf_reflected_power_from_transmitter_port
        type : b12
      - id: trxvutx_instantaneous_rf_forward_power_from_transmitter_port
        type : b12
      - id: trxvutx_supply_voltage
        type : b12
      - id: trxvutx_total_supply_current
        type : b12
      - id: trxvutx_transmitter_current
        type : b12
      - id: trxvutx_receiver_current
        type : b12
      - id: trxvutx_power_amplifier_current
        type : b12
      - id: trxvutx_power_amplifier_temperature
        type : b12 
      - id: trxvutx_local_oscillator_temperature
        type : b12
      - id: trxvu_tx_uptime
        type: u4
      - id: trxvu_tx_state
        type: u1 

# référence table 7.5.1 TRXVU interface control document
    instances:
        trxvurx_instantaneous_received_signal_doppler_hz:
          value: (trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        trxvurx_instantaneous_received_signal_strength_dbm:
          value: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        trxvurx_supply_voltage_v:
          value: trxvurx_supply_voltage*0.00488
        trxvurx_total_supply_current_ma:
          value: trxvurx_total_supply_current*0.16643964
        trxvurx_transmitter_current_ma:
          value: trxvurx_transmitter_current*0.16643964
        trxvurx_receiver_current_ma:
          value: trxvurx_receiver_current*0.16643964
        trxvurx_power_amplifier_current_ma:
          value: 1000.0 * trxvurx_power_amplifier_current*0.16643964
        trxvurx_power_amplifier_temperature_c:
          value: (trxvurx_power_amplifier_temperature)*-0.07669+195.6037
        trxvurx_local_oscillator_temperature_c:
          value: (trxvurx_local_oscillator_temperature)*-0.07669+195.6037
        trxvu_rx_uptime_raw:
          value: trxvu_rx_uptime        
        trxvutx_instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_supply_voltage_v:
          value: 0.00488 * trxvutx_supply_voltage   
        trxvutx_total_supply_current_ma: 
          value: 0.16643964 * trxvutx_total_supply_current 
        trxvutx_transmitter_current_ma:
          value: trxvutx_transmitter_current * 0.16643964
        trxvutx_receiver_current_ma:
          value: trxvutx_receiver_current * 0.16643964
        trxvutx_power_amplifier_current_ma:
          value: 1000.0 * trxvutx_power_amplifier_current * 0.16643964
        trxvutx_power_amplifier_temperature_c:
          value: trxvutx_power_amplifier_temperature * -0.07669 + 195.6037
        trxvutx_local_oscillator_temperature_c:
          value: trxvutx_local_oscillator_temperature *  -0.07669 + 195.6037
        trxvu_tx_uptime_raw:
          value: trxvu_tx_uptime
        trxvu_tx_state_raw:
          value: trxvu_tx_state

 
    


################################################################################
#
#   imtq  HK
#
#  Digital Voltage   16   Unsigned 16bits 
# Analog Voltage   16   Unsigned 16bits 
# Digital Current   16   Unsigned 16bits 
# Analog Current   16   Unsigned 16bits 
# Measure Coil X Current   16   Unsigned 16bits 
# Measure Coil Y Current   16   Unsigned 16bits 
# Measure Coil Z Current   16   Unsigned 16bits 
# Measure Coil X Temperature   16   Unsigned 16bits 
# Measure Coil Y Temperature   16   Unsigned 16bits 
# Measure Coil Z Temperature   16   Unsigned 16bits 
# MCU Temperature   16   Unsigned 16bits 
# iMTQ system state mode.   8   Unsigned 8bits 
# iMTQ system state error.   8   Unsigned 8bits 
# iMTQ system state configuration.   8   Unsigned 8bits 
# iMTQ system state uptime.   32   Unsigned 32bits 
# Raw Mag X   32   Signed 32bits 
# Raw Mag Y   32   Signed 32bits 
# Raw Mag Z   32   Signed 32bits 
# COILACT    8   Unsigned 8bits 
#
################################################################################        
        
  imtq_hk:
    seq:
      - id: digitale_voltage
        type: u2  
      - id: analog_voltage
        type: u2   
      - id: digital_current
        type: u2  
      - id: analog_current
        type: u2  
      - id: measure_coil_x_current
        type: u2  
      - id: measure_coil_y_current
        type: u2  
      - id: measure_coil_z_current
        type: u2  
      - id: measure_coil_x_temperature
        type: u2  
      - id: measure_coil_y_temperature
        type: u2  
      - id: measure_coil_z_temperature
        type: u2  
      - id: mcu_temperature
        type: u2  
      - id: imtq_system_state_mode
        type: u1 
      - id: imtq_system_state_error
        type: u1  
      - id: imtq_system_state_configuration
        type: u1
      - id: imtq_system_state_uptime
        type: u4
      - id: raw_mag_x
        type: u4
      - id: raw_mag_y
        type: u4
      - id: raw_mag_z
        type: u4 
      - id: c_o_i_l_a_c_t
        type: u1 

    instances:
        digitale_voltage_v:
          value: 2 *  (2.5/4095) * digitale_voltage   
        analog_voltage_v: 
          value: 2 *  (2.5/4095) * analog_voltage
        digital_current_raw:
          value: digital_current  
        analog_current_raw:
          value: analog_current 
        measure_coil_x_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_ma:
          value:   1000.0 * (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_ma:
          value:  1000.0 *  (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_c:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_c:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_c:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_c:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 / 0.00225
        imtq_system_state_mode_raw:
          value: imtq_system_state_mode 
        imtq_system_state_error_raw:
          value: imtq_system_state_error  
        imtq_system_state_configuration_raw:
          value: imtq_system_state_configuration
        imtq_system_state_uptime_raw:
          value: imtq_system_state_uptime 
        raw_mag_x_raw:
          value: raw_mag_x
        raw_mag_y_raw:
          value: raw_mag_y
        raw_mag_z_raw:
          value: raw_mag_z
        c_o_i_l_a_c_t_raw:
          value: c_o_i_l_a_c_t          


################################################################################
#
#   Mainboard All Science
#
################################################################################      
  mainboard_all_science:
    seq:
      - id: mainboard_science_time
        type: u4
      - id: teach_wear_on
        type: u1
      - id: frequence_of_acquisitions
        type: u2
      - id: gain
        type: u4
      - id: number_of_acquisition_commanded
        type: u2
      - id: number_of_real_acquisition
        type: u2
      - id: hk_plus_5v
        type: u4
      - id: hk_minus_5v
        type: u4
      - id: hk_minus_5v_polar
        type: u4
      - id: hk_temp_adc
        type: u4
      - id: hk_fee_plus_x_vref
        type: u4
      - id: hk_fee_minus_x_vref
        type: u4
      - id: hk_fee_plus_y_vref
        type: u4
      - id: hk_fee_minus_y_vref
        type: u4
      - id: fee_plus_x_ers_1_signal
        type: u4
      - id: fee_plus_x_ers_1_temperature
        type: u4
      - id: fee_plus_x_ers_2_signal
        type: u4
      - id: fee_plus_x_ers_2_temperature
        type: u4
      - id: fee_plus_x_ers_3_signal
        type: u4
      - id: fee_plus_x_ers_3_temperature
        type: u4
      - id: fee_plus_x_uvs_signal
        type: u4
      - id: fee_minus_x_ers_1_signal
        type: u4
      - id: fee_minus_x_ers_1_temperature
        type: u4
      - id: fee_minus_x_ers_2_signal
        type: u4
      - id: fee_minus_x_ers_2_temperature
        type: u4
      - id: fee_minus_x_ers_3_signal
        type: u4
      - id: fee_minus_x_ers_3_temperature
        type: u4
      - id: fee_minus_x_uvs_signal
        type: u4
      - id: fee_plus_y_ers_1_signal
        type: u4
      - id: fee_plus_y_ers_1_temperature
        type: u4
      - id: fee_plus_y_ers_2_signal
        type: u4
      - id: fee_plus_y_ers_2_temperature
        type: u4
      - id: fee_plus_y_ers_3_signal
        type: u4
      - id: fee_plus_y_ers_3_temperature
        type: u4
      - id: fee_plus_y_uvs_signal
        type: u4
      - id: fee_minus_y_ers_1_signal
        type: u4
      - id: fee_minus_y_ers_1_temperature
        type: u4
      - id: fee_minus_y_ers_2_signal
        type: u4
      - id: fee_minus_y_ers_2_temperature
        type: u4
      - id: fee_minus_y_ers_3_signal
        type: u4
      - id: fee_minus_y_ers_3_temperature
        type: u4
      - id: fee_minus_y_uvs_signal
        type: u4
      - id: teachwear_acc_x
        type: u2
      - id: teachwear_acc_y
        type: u2
      - id: teachwear_acc_z
        type: u2
      - id: teachwear_deg_c
        type: u2
      - id: teachwear_gyro_x
        type: u2
      - id: teachwear_gyro_y
        type: u2
      - id: teachwear_gyro_z
        type: u2
      - id: teachwear_magn_x
        type: u2
      - id: teachwear_magn_y
        type: u2
      - id: teachwear_magn_z
        type: u2
      - id: teachwear_state
        type: u1
      - id: teachwear_reset_reason
        type: u1
      - id: teachwear_crc
        type: u2  
      - id: nb_tm_since_first_start
        type: u4
    instances:
     mainboard_science_time_raw:
      value: mainboard_science_time
     teach_wear_on_raw:
      value: teach_wear_on
     frequence_of_acquisitions_raw:
      value: frequence_of_acquisitions
     gain_raw:
      value: gain
     number_of_acquisition_commanded_raw:
      value: number_of_acquisition_commanded
     number_of_real_acquisition_raw:
      value: number_of_real_acquisition
     hk_plus_5v_raw:
      value: hk_plus_5v
     hk_minus_5v_raw:
      value: hk_minus_5v
     hk_minus_5v_polar_raw:
      value: hk_minus_5v_polar
     hk_temp_adc_raw:
      value: hk_temp_adc
     hk_fee_plus_x_vref_raw:
      value: hk_fee_plus_x_vref
     hk_fee_minus_x_vref_raw:
      value: hk_fee_minus_x_vref
     hk_fee_plus_y_vref_raw:
      value: hk_fee_plus_y_vref
     hk_fee_minus_y_vref_raw:
      value: hk_fee_minus_y_vref
     fee_plus_x_ers_1_signal_raw:
      value: fee_plus_x_ers_1_signal
     fee_plus_x_ers_1_temperature_raw:
      value: fee_plus_x_ers_1_temperature
     fee_plus_x_ers_2_signal_raw:
      value: fee_plus_x_ers_2_signal
     fee_plus_x_ers_2_temperature_raw:
      value: fee_plus_x_ers_2_temperature
     fee_plus_x_ers_3_signal_raw:
      value: fee_plus_x_ers_3_signal
     fee_plus_x_ers_3_temperature_raw:
      value: fee_plus_x_ers_3_temperature
     fee_plus_x_uvs_signal_raw:
      value: fee_plus_x_uvs_signal
     fee_minus_x_ers_1_signal_raw:
      value: fee_minus_x_ers_1_signal
     fee_minus_x_ers_1_temperature_raw:
      value: fee_minus_x_ers_1_temperature
     fee_minus_x_ers_2_signal_raw:
      value: fee_minus_x_ers_2_signal
     fee_minus_x_ers_2_temperature_raw:
      value: fee_minus_x_ers_2_temperature
     fee_minus_x_ers_3_signal_raw:
      value: fee_minus_x_ers_3_signal
     fee_minus_x_ers_3_temperature_raw:
      value: fee_minus_x_ers_3_temperature
     fee_minus_x_uvs_signal_raw:
      value: fee_minus_x_uvs_signal
     fee_plus_y_ers_1_signal_raw:
      value: fee_plus_y_ers_1_signal
     fee_plus_y_ers_1_temperature_raw:
      value: fee_plus_y_ers_1_temperature
     fee_plus_y_ers_2_signal_raw:
      value: fee_plus_y_ers_2_signal
     fee_plus_y_ers_2_temperature_raw:
      value: fee_plus_y_ers_2_temperature
     fee_plus_y_ers_3_signal_raw:
      value: fee_plus_y_ers_3_signal
     fee_plus_y_ers_3_temperature_raw:
      value: fee_plus_y_ers_3_temperature
     fee_plus_y_uvs_signal_raw:
      value: fee_plus_y_uvs_signal
     fee_minus_y_ers_1_signal_raw:
      value: fee_minus_y_ers_1_signal
     fee_minus_y_ers_1_temperature_raw:
      value: fee_minus_y_ers_1_temperature
     fee_minus_y_ers_2_signal_raw:
      value: fee_minus_y_ers_2_signal
     fee_minus_y_ers_2_temperature_raw:
      value: fee_minus_y_ers_2_temperature
     fee_minus_y_ers_3_signal_raw:
      value: fee_minus_y_ers_3_signal
     fee_minus_y_ers_3_temperature_raw:
      value: fee_minus_y_ers_3_temperature
     fee_minus_y_uvs_signal_raw:
      value: fee_minus_y_uvs_signal
     teachwear_acc_x_raw:
      value: teachwear_acc_x
     teachwear_acc_y_raw:
      value:  teachwear_acc_y
     teachwear_acc_z_raw:
      value: teachwear_acc_z
     teachwear_deg_c_raw:
      value: teachwear_deg_c
     teachwear_gyro_x_raw:
      value: teachwear_gyro_x
     teachwear_gyro_y_raw:
      value: teachwear_gyro_y
     teachwear_gyro_z_raw:
      value: teachwear_gyro_z
     teachwear_magn_x_raw:
      value: teachwear_magn_x
     teachwear_magn_y_raw:
      value: teachwear_magn_y
     teachwear_magn_z_raw:
      value: teachwear_magn_z
     teachwear_state_raw:
      value: teachwear_state
     teachwear_reset_reason_raw:
      value: teachwear_reset_reason
     teachwear_c_r_c_raw:
      value: teachwear_crc
     nb_tm_since_first_start_raw:
      value: nb_tm_since_first_start


################################################################################
#
#   AMSAT ASCII
#
################################################################################ 
  amsat_ascii:
    seq:
      - id: message
        type: str
        size-eos: true
        encoding: UTF-8
    instances:
     message_str:
      value: message
        
  mainboard_hk:
    seq:
      - id: mainboard_hk_time
        type: u4
      - id: hk_plus_5_v
        type: u2
      - id: hk_minus_5_v
        type: u2
      - id: hk_minus_polar
        type: u2
      - id: hk_temp_a_d_c
        type: u2
      - id: hk_fee_plus_x_vref
        type: u2
      - id: hk_fee_minus_x_vref
        type: u2
      - id: hk_fee_plus_y_vref
        type: u2
      - id: hk_fee_minus_y_vref
        type: u2
    instances:
     mainboard_h_k_time_raw:
      value: mainboard_hk_time
     hk_plus_5_v_raw:
      value: hk_plus_5_v
     hk_minus_5_v_raw:
      value: hk_minus_5_v
     hk_minus_polar_raw:
      value: hk_minus_polar
     hk_temp_a_d_c_raw:
      value: hk_temp_a_d_c
     hk_fee_plus_x_vref_raw:
      value: hk_fee_plus_x_vref
     hk_fee_minus_x_vref_raw:
      value: hk_fee_minus_x_vref
     hk_fee_plus_y_vref_raw:
      value: hk_fee_plus_y_vref
     hk_fee_minus_y_vref_raw:
      value: hk_fee_minus_y_vref



     
          
################################################################################
#
#   beacon
#
################################################################################           
          
  beacon:
    seq:
      - id: sw_mode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reset_order
        type: u1
      - id: nb_reset
        type: u1
      - id: format_sdcard_order
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_tc_ping_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: trxvutx_instantaneous_rf_reflected_power_from_transmitter_port
        type: b12
      - id: trxvutx_instantaneous_rf_forward_power_from_transmitter_port
        type: b12
      - id: trxvutx_supply_voltage
        type: b12
      - id: trxvutx_total_supply_current
        type: b12
      - id: trxvutx_transmitter_current
        type: b12
      - id: trxvutx_receiver_current
        type: b12
      - id: trxvutx_power_amplifier_current
        type: b12
      - id: trxvutx_power_amplifier_temperature
        type: b12
      - id: trxvutx_local_oscillator_temperature
        type: b12
      - id: trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvurx_supply_voltage
        type: b12
      - id: trxvurx_total_supply_current
        type: b12
      - id: trxvurx_transmitter_current
        type: b12
      - id: trxvurx_receiver_current
        type: b12
      - id: trxvurx_power_amplifier_current
        type: b12
      - id: trxvurx_power_amplifier_temperature
        type: b12
      - id: trxvurx_local_oscillator_temperature
        type: b12
      - id: imtq_system_state_mode
        type: u1
      - id: measure_coil_x_current
        type: u2
      - id: measure_coil_y_current
        type: u2
      - id: measure_coil_z_current
        type: u2
      - id: measure_coil_x_temperature
        type: u2
      - id: measure_coil_y_temperature
        type: u2
      - id: measure_coil_z_temperature
        type: u2
      - id: mcu_temperature
        type: u2
      - id: side_a_ants_temperature
        type: u2
      - id: side_a_ants_deployment_status
        type: u2
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: v_dist_input_raw
        type: u2
      - id: i_dist_input_raw
        type: u2
      - id: p_dist_input_raw
        type: u2
      - id: v_batt_input_raw
        type: u2
      - id: i_batt_input_raw
        type: u2
      - id: p_batt_input_raw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp_2_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_obc_00
        type: u2
      - id: i_obc_00
        type:  u2
      - id: p_obc_00
        type:  u2
      - id: v_obc_01
        type: u2
      - id: i_obc_01
        type:  u2
      - id: p_obc_01
        type:  u2
      - id: v_obc_02
        type: u2
      - id: i_obc_02
        type:  u2
      - id: p_obc_02
        type:  u2
      - id: v_obc_03
        type: u2
      - id: i_obc_03
        type:  u2
      - id: p_obc_03
        type:  u2
      - id: v_obc_05
        type: u2
      - id: i_obc_05
        type:  u2
      - id: p_obc_05
        type:  u2
      - id: v_obc_06
        type: u2
      - id: i_obc_06
        type:  u2
      - id: p_obc_06
        type:  u2
      - id: status_stid
        type: u1
      - id: status_ivid
        type: u1
      - id: status_rc
        type: u1
      - id: status_bid
        type: u1
      - id: status_cmderr
        type: b4
      - id: status_stat
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2     
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2      
      - id: photodiode_1
        type: u2
      - id: photodiode_2
        type: u2
      - id: photodiode_3
        type: u2
      - id: photodiode_4
        type: u2
      - id: photodiode_5
        type: u2
      - id: photodiode_6
        type: u2
      - id: panel_temperature_1
        type: s4
      - id: panel_temperature_2
        type: s4
      - id: panel_temperature_3
        type: s4
      - id: panel_temperature_4
        type: s4
      - id: panel_temperature_5
        type: s4
      - id: panel_temperature_6
        type: s4    

    instances: 

        sw_mode_raw:
          value:  sw_mode
          doc: |
           : mode value 
           MODE_INIT = 0 
           MODE_DETUMBLING = 1 
           MODE_STANDBY = 2 
           MODE_OPERATIONAL = 3 
           MODE_SAFE = 4 
           MODE_TRANSPONDER = 5
        last_reset_reason_raw:
          value:  last_reset_reason
          doc: |
           : last reset value
           First start = 0 
           TC Init received = 0x80 
           No TC since 4 days = 0x81 
           Unknown reason = 0x81
        reset_order_raw:
          value:  reset_order
          doc: |
           Order by TC = 0xCA
           No order = 0
        nb_reset_raw:
          value:  nb_reset
        format_sdcard_order_raw:
          value:  format_sdcard_order
          doc: |
           Order to Format SdCard 0 = 0
           Order to Format SdCard 1 = 1
           Order to NOT Format SdCard 0 = 0xAC
           Order to NOT Format SdCard 1 = 0xAD

        deploy_antennas_system_raw:
          value:  deploy_antennas_system
          doc : |
           : value 
           Nominal = 0 
           No deploy = 0x11 
           Deployment Debug = 0xDB
        nb_tm_since_first_start_raw:
          value:  nb_tm_since_first_start
        nb_tc_since_first_start_raw:
          value:  nb_tc_since_first_start
        nb_tc_ping_since_first_start_raw:
          value:  nb_tc_ping_since_first_start
        nb_bad_tc_since_first_start_raw:
          value:  nb_bad_tc_since_first_start
        nb_tm_in_sdcard_raw:
          value:  nb_tm_in_sdcard
        trxvutx_instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * trxvutx_instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: 1000.0 * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * trxvutx_instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        trxvutx_supply_voltage_v:
          value: 0.00488 * trxvutx_supply_voltage 
        trxvutx_total_supply_current_ma: 
          value: 0.16643964 * trxvutx_total_supply_current 
        trxvutx_transmitter_current_ma:
          value: trxvutx_transmitter_current * 0.16643964
        trxvutx_receiver_current_ma:
          value: trxvutx_receiver_current * 0.16643964
        trxvutx_power_amplifier_current_ma:
          value: 1000.0 * trxvutx_power_amplifier_current * 0.16643964
        trxvutx_power_amplifier_temperature_c:
          value: trxvutx_power_amplifier_temperature * -0.07669 + 195.6037
        trxvutx_local_oscillator_temperature_c:
          value: trxvutx_local_oscillator_temperature * -0.07669 + 195.6037
        trxvurx_instantaneous_received_signal_doppler_hz:
          value: (trxvurx_instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        trxvurx_instantaneous_received_signal_strength_dbm:
          value: trxvurx_instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        trxvurx_supply_voltage_v:
          value: 0.00488 * trxvurx_supply_voltage   
        trxvurx_total_supply_current_ma: 
          value: 0.16643964 * trxvurx_total_supply_current
        trxvurx_transmitter_current_ma:
          value: trxvurx_transmitter_current * 0.16643964
        trxvurx_receiver_current_ma:
          value: trxvurx_receiver_current * 0.16643964
        trxvurx_power_amplifier_current_ma:
          value: 1000.0 *  trxvurx_power_amplifier_current *0.16643964
        trxvurx_power_amplifier_temperature_c:
          value: trxvurx_power_amplifier_temperature *-0.07669+195.6037
        trxvurx_local_oscillator_temperature_c:
          value: trxvurx_local_oscillator_temperature *-0.07669+195.6037
        imtq_system_state_mode_raw:
          value: imtq_system_state_mode
          doc:  |
           value :
           IDLE = 0 
           SELFTEST = 1 
           DETUMBLE = 2
        measure_coil_x_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_ma:
          value:  1000.0 *  (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_ma:
          value:  1000.0 * (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_c:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_c:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_c:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_c:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 /0.00225
        side_a_ants_temperature_raw:
          value: side_a_ants_temperature
        side_a_ants_deployment_status_raw:
          value: side_a_ants_deployment_status
        volt_brd_sup_raw_v: 
         value: volt_brd_sup_raw * 1000.0 / 819.0
        # ?? To be check - not coherent 
        temp_raw_t: 
         value: ((temp_raw -1168)*220.0/9.0 )/ 100.0
        v_dist_input_raw_v: 
         value: (v_dist_input_raw * 125.0/128.0)/ 1000.0
        i_dist_input_raw_ma: 
         value: i_dist_input_raw * 3125.0/10240.0 
        p_dist_input_raw_mw: 
         value: p_dist_input_raw *3125.0 / 3200.0
        v_batt_input_raw_v: 
         value: (v_batt_input_raw * 125.0/128.0)/ 1000.0
        i_batt_input_raw_ma: 
         value: 1000.0 * ( i_batt_input_raw * 3125.0/10240.0 )
        p_batt_input_raw_mw:
         value: p_batt_input_raw *3125.0 / 3200.0
        stat_obc_on_raw:
          value: stat_obc_on
          doc: |
             bit n = 1 indicates the channel n is ON 9 firsts bits used
        stat_obc_ocf_raw:
          value: stat_obc_ocf
          doc: |
              bit n = 1 indicates a overcurrent on the channel n 9 firsts bits used
        bat_stat_raw:
          value: bat_stat
        bat_temp_2_raw_t: 
         value: bat_temp_2_raw * -0.047715407918 +98.38261483
        volt_vd0_raw:
          value: volt_vd0
        volt_vd1_raw:
          value: volt_vd1
        volt_vd2_raw: 
          value: volt_vd2
        v_obc_00_v:
         value: (v_obc_00  *125.0/128.0)/ 1000.0
        i_obc_00_ma:
         value: i_obc_00 *3125.0/20480.0
        p_obc_00_mw:
         value: p_obc_00 *3125.0 / 6400.0
        v_obc_01_v:
         value: ( v_obc_01  *125.0/128.0)/ 1000.0
        i_obc_01_ma:
         value: i_obc_01 *3125.0/20480.0
        p_obc_01_mw:
         value: p_obc_01 *3125.0 / 6400.0
        v_obc_02_v:
         value: (v_obc_02  *125.0/128.0)/ 1000.0
        i_obc_02_ma:
         value: i_obc_02 *3125.0/20480.0
        p_obc_02_mw:
         value: p_obc_02 *3125.0 / 6400.0   
        v_obc_03_v:
         value: (v_obc_03  *125.0/128.0)/ 1000.0
        i_obc_03_ma:
         value: i_obc_03 *3125.0/20480.0
        p_obc_03_mw:
         value: p_obc_03 *3125.0 / 6400.0
        v_obc_05_v:
         value: (v_obc_05  *125.0/128.0)/ 1000.0
        i_obc_05_ma:
         value: i_obc_05 *3125.0/20480.0
        p_obc_05_mw:
         value: p_obc_05 *3125.0 / 6400.0
        v_obc_06_v:
         value: (v_obc_06  *125.0/128.0)/ 1000.0
        i_obc_06_ma:
         value: i_obc_06 *3125.0/20480.0
        p_obc_06_mw :
         value: p_obc_06 *3125.0 / 6400.0
        status_stid_raw:
          value: status_stid
        status_ivid_raw:
          value: status_ivid
        status_rc_raw:
          value: status_rc
        status_bid_raw:
          value: status_bid
        status_cmderr_raw:
          value: status_cmderr
        status_stat_raw:
          value: status_stat
        mode_raw:
          value: mode
          doc: |
           value :
           0 = Startup 
           1 = Nominal 
           2 = Safety 
           3 = Emergency low power 8
          
        conf_raw:
          value: conf
          doc: |
           value : 
           0 = Parameters have not been altered since the last load/save.
           1 = Parameters have been altered since the last load/save.
        reset_cause_raw:
          value: reset_cause
          doc: |
           value : 
           0 = Power-on; system returned from an unpowered state (e.g. power cycle). 
           1 = Watchdog; system was reset due to watchdog timeout, caused by a too-long delay between command interactions with the parent system. 
           2 = Commanded; system was reset after having received a reset command. 
           3 = Control system reset; an upset in the EPS control system caused a reset. 
           4 = Emlopo; emergency low power mode was engaged because the input voltage dropped below the threshold.
        uptime_raw:
          value: uptime
        error_raw:
          value: error
        rc_cnt_pwron_raw:
          value: rc_cnt_pwron
        rc_cnt_wdg_raw:
          value: rc_cnt_wdg
        rc_cnt_cmd_raw:
          value: rc_cnt_cmd
        rc_cnt_mcu_raw:
          value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
          value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
          value: prevcmd_elapsed
        photodiode_1_raw:
          value: photodiode_1
        photodiode_2_raw:
          value: photodiode_2
        photodiode_3_raw:
          value: photodiode_3
        photodiode_4_raw:
          value: photodiode_4
        photodiode_5_raw:
          value: photodiode_5
        photodiode_6_raw:
          value: photodiode_6
        panel_temperature_1_c:
          value:  panel_temperature_1 / 1024.0
        panel_temperature_2_c:
          value:  panel_temperature_2 / 1024.0
        panel_temperature_3_c:
          value:  panel_temperature_3 / 1024.0
        panel_temperature_4_c:
          value:  panel_temperature_4 / 1024.0
        panel_temperature_5_c:
          value:  panel_temperature_5 / 1024.0
        panel_temperature_6_c:
          value:  panel_temperature_6 / 1024.0

